@@ -227,8 +227,7 @@ class Downloader:
 
             if not await self.SQL_Helper.sql_check_old_existing(url_path) and not fake_download:
                 await self.download_session.download_file(media, partial_file, current_throttle, resume_point,
-                                                          self.File_Lock, self.proxy, headers, original_filename,
-                                                          file_task)
+                                                          self.proxy, headers, file_task)
                 partial_file.rename(complete_file)
 
             await self.SQL_Helper.mark_complete(url_path, original_filename)
@@ -275,6 +274,17 @@ class Downloader:
                         self.current_attempt.pop(url_path)
                     await self.output_failed(media, e)
                     return
+                if e.code == 503:
+                    if hasattr(e, "message"):
+                        logging.debug(f"\n{media.url} ({e.message})")
+                    await log(f"Failed Download: {media.filename}", quiet=True)
+                    overall_file_progress.advance(self.files.failed_files_task_id, 1)
+                    self.files.failed_files += 1
+                    if url_path in self.current_attempt.keys():
+                        self.current_attempt.pop(url_path)
+                    await self.output_failed(media, e)
+                    return
+
                 logger.debug("Error status code: " + str(e.code))
                 new_error.code = e.code
 
@@ -381,7 +391,7 @@ async def download_forums(args: dict, Forums: ForumItem, SQL_Helper: SQLHelper,
     files = Files(overall_file_progress.add_task("[green]Completed", total=total_files),
                   overall_file_progress.add_task("[yellow]Skipped", total=total_files),
                   overall_file_progress.add_task("[red]Failed", total=total_files))
-    with Live(progress_table, refresh_per_second=30):
+    with Live(progress_table, refresh_per_second=10):
         forum_task = forum_progress.add_task("[orange3]FORUM THREADS", total=len(Forums.threads))
         for title, Cascade in Forums.threads.items():
             cascade_task = cascade_progress.add_task("[light_salmon3]" + title.upper(), total=len(Cascade.domains))
