@@ -79,10 +79,11 @@ class ScrapeMapper:
         self.jpgfish_limiter = AsyncRateLimiter(10)
         self.bunkr_limiter = AsyncRateLimiter(15)
         self.coomeno_limiter = AsyncRateLimiter(8)
-        self.gofile_limiter = AsyncRateLimiter(8)
+        self.gofile_limiter = AsyncRateLimiter(max_calls=1, period=2)
 
         self.gofile_semaphore = asyncio.Semaphore(1)
         self.jpgfish_semaphore = asyncio.Semaphore(5)
+        self.cyberfile_semaphore = asyncio.Semaphore(2)
         self.simpcity_semaphore = asyncio.Semaphore(1)
         self.socialmediagirls_semaphore = asyncio.Semaphore(1)
         self.xbunker_semaphore = asyncio.Semaphore(1)
@@ -147,7 +148,8 @@ class ScrapeMapper:
         cyberfile_session = ScrapeSession(self.client)
         if not self.cyberfile_crawler:
             self.cyberfile_crawler = CyberFileCrawler(quiet=self.quiet, SQL_Helper=self.SQL_Helper)
-        domain_obj = await self.cyberfile_crawler.fetch(cyberfile_session, url)
+        async with self.cyberfile_semaphore:
+            domain_obj = await self.cyberfile_crawler.fetch(cyberfile_session, url)
         await self.handle_additions("cyberfile", None, domain_obj, title)
         await cyberfile_session.exit_handler()
 
@@ -350,5 +352,7 @@ class ScrapeMapper:
         else:
             await log(f"[yellow]Not Supported: {str(url_to_map)}[/yellow]", quiet=self.quiet)
             if self.unsupported_output:
+                title = title.encode("ascii", "ignore")
+                title = title.decode().strip()
                 async with aiofiles.open(self.unsupported_file, mode='a') as f:
                     await f.write(f"{str(url_to_map)},{str(referer)},{title}\n")
